#
# spec file for package perl-Encode
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Encode
Name:           perl-Encode
Version:        3.210.0
Release:        2.4
%define cpan_version 3.21
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Character encodings in Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DA/DANKOGAI/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        perl-Encode-rpmlintrc
Source2:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.92
BuildRequires:  perl(parent) >= 0.221
Requires:       perl(parent) >= 0.221
Provides:       perl(Encode) = %{version}
Provides:       perl(Encode::Alias) = 2.25
Provides:       perl(Encode::CJKConstants) = 2.200.0
Provides:       perl(Encode::CN::HZ) = 2.10
Provides:       perl(Encode::Config) = 2.500.0
Provides:       perl(Encode::Encoder) = 2.300.0
Provides:       perl(Encode::Encoding) = 2.800.0
Provides:       perl(Encode::GSM0338) = 2.10
Provides:       perl(Encode::Guess) = 2.800.0
Provides:       perl(Encode::JP::H2Z) = 2.200.0
Provides:       perl(Encode::JP::JIS7) = 2.800.0
Provides:       perl(Encode::KR::2022_KR) = 2.400.0
Provides:       perl(Encode::MIME::Header) = 2.29
Provides:       perl(Encode::MIME::Header::ISO_2022_JP) = 1.900.0
Provides:       perl(Encode::MIME::Name) = 1.300.0
Provides:       perl(Encode::UTF_EBCDIC)
Provides:       perl(Encode::Unicode::UTF7) = 2.10
Provides:       perl(Encode::XS)
Provides:       perl(Encode::utf8)
Provides:       perl(encoding) = 3.00
%undefine       __perllib_provides
%{perl_requires}

%description
The 'Encode' module provides the interface between Perl strings and the
rest of the system. Perl strings are sequences of _characters_.

The repertoire of characters that Perl can represent is a superset of those
defined by the Unicode Consortium. On most platforms the ordinal values of
a character as returned by 'ord(_S_)' is the _Unicode codepoint_ for that
character. The exceptions are platforms where the legacy encoding is some
variant of EBCDIC rather than a superset of ASCII; see perlebcdic.

During recent history, data is moved around a computer in 8-bit chunks,
often called "bytes" but also known as "octets" in standards documents.
Perl is widely used to manipulate data of many types: not only strings of
characters representing human or computer languages, but also "binary"
data, being the machine's representation of numbers, pixels in an image, or
just about anything.

When Perl is processing "binary data", the programmer wants Perl to process
"sequences of bytes". This is not a problem for Perl: because a byte has
256 possible values, it easily fits in Perl's much larger "logical
character".

This document mostly explains the _how_. perlunitut and perlunifaq explain
the _why_.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
# MANUAL BEGIN
%__rm -f ${RPM_BUILD_ROOT}/usr/bin/enc2xs
%__rm -f ${RPM_BUILD_ROOT}/usr/bin/encguess
%__rm -f ${RPM_BUILD_ROOT}/usr/bin/piconv
%__rm -f ${RPM_BUILD_ROOT}/usr/share/man/man1/enc2xs.1*
%__rm -f ${RPM_BUILD_ROOT}/usr/share/man/man1/encguess.1*
%__rm -f ${RPM_BUILD_ROOT}/usr/share/man/man1/piconv.1*
# MANUAL END
%perl_gen_filelist

%files -f %{name}.files
%doc AUTHORS Changes README

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Mon Feb 26 2024 Tina Müller <timueller+perl@suse.de>
- updated to 3.21
  see /usr/share/doc/packages/perl-Encode/Changes
* Fri Nov 10 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.20
  see /usr/share/doc/packages/perl-Encode/Changes
* Fri Aug  5 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.19
  see /usr/share/doc/packages/perl-Encode/Changes
* Sun Jun 26 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.18
  see /usr/share/doc/packages/perl-Encode/Changes
* Fri Apr  8 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.17
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Oct 14 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.16
  see /usr/share/doc/packages/perl-Encode/Changes
* Sat Oct  9 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.15
  see /usr/share/doc/packages/perl-Encode/Changes
* Tue Aug 10 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.12
  see /usr/share/doc/packages/perl-Encode/Changes
* Sat Jul 24 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.11
  see /usr/share/doc/packages/perl-Encode/Changes
* Wed May 19 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.10
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Dec  3 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.08
  see /usr/share/doc/packages/perl-Encode/Changes
* Tue Jul 28 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.07
  see /usr/share/doc/packages/perl-Encode/Changes
* Sun May  3 2020 Tina Müller <timueller+perl@suse.de>
  updated to 3.06
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Mar 19 2020 <timueller+perl@suse.de>
- updated to 3.05
  see /usr/share/doc/packages/perl-Encode/Changes
* Wed Mar 11 2020 <timueller+perl@suse.de>
- updated to 3.04
  see /usr/share/doc/packages/perl-Encode/Changes
* Tue Mar  3 2020 <timueller+perl@suse.de>
- updated to 3.03
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Dec 26 2019 <timueller+perl@suse.de>
- updated to 3.02
  see /usr/share/doc/packages/perl-Encode/Changes
* Wed Mar 13 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.01
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Jan 31 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.00
  see /usr/share/doc/packages/perl-Encode/Changes
* Mon Jan 21 2019 Stephan Kulow <coolo@suse.com>
- updated to 2.99
  see /usr/share/doc/packages/perl-Encode/Changes
* Mon Apr 23 2018 coolo@suse.com
- updated to 2.98
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Feb 22 2018 coolo@suse.com
- updated to 2.97
  see /usr/share/doc/packages/perl-Encode/Changes
* Mon Feb 12 2018 coolo@suse.com
- updated to 2.96
  see /usr/share/doc/packages/perl-Encode/Changes
* Wed Jan 10 2018 coolo@suse.com
- updated to 2.94
  see /usr/share/doc/packages/perl-Encode/Changes
* Sun Oct  8 2017 coolo@suse.com
- updated to 2.93
  see /usr/share/doc/packages/perl-Encode/Changes
* Tue Jul 25 2017 coolo@suse.com
- updated to 2.92
  see /usr/share/doc/packages/perl-Encode/Changes
* Fri Jun 23 2017 coolo@suse.com
- updated to 2.91
  see /usr/share/doc/packages/perl-Encode/Changes
* Wed Jun 14 2017 coolo@suse.com
- updated to 2.90
  see /usr/share/doc/packages/perl-Encode/Changes
* Fri May  5 2017 coolo@suse.com
- updated to 2.89
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Dec  1 2016 coolo@suse.com
- updated to 2.88
  see /usr/share/doc/packages/perl-Encode/Changes
* Sat Oct 29 2016 coolo@suse.com
- updated to 2.87
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Aug 11 2016 coolo@suse.com
- updated to 2.86
  see /usr/share/doc/packages/perl-Encode/Changes
* Fri Aug  5 2016 coolo@suse.com
- updated to 2.85
  see /usr/share/doc/packages/perl-Encode/Changes
* Tue Apr 12 2016 coolo@suse.com
- updated to 2.84
  see /usr/share/doc/packages/perl-Encode/Changes
* Mon Apr  4 2016 coolo@suse.com
- updated to 2.83
  see /usr/share/doc/packages/perl-Encode/Changes
* Sun Feb  7 2016 coolo@suse.com
- updated to 2.82
  see /usr/share/doc/packages/perl-Encode/Changes
* Wed Jan 27 2016 coolo@suse.com
- updated to 2.80
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Feb 26 2015 darin@darins.net
- update to 2.7.0
  + Makefile.PL
    add bin/encguess to EXE_FILES
  2.69 2015/02/05 10:35:11
  + bin/encguess
    Refactored so that
  * does not depend on non-core module (File::Slurp in particular)
  * PODified document
  * -s "encA encB" to -s encA,encB which is more shell-friendly
  * and more
  + MANIFEST
  + bin/encguess
    Pulled: Added CLI wrapper for Encode::Guess
    https://github.com/dankogai/p5-encode/pull/32
  + Unicode/Unicode.pm
    Pulled: Bump $VERSION in module changed since Encode-2.60
    https://github.com/dankogai/p5-encode/pull/31
  For a complete list of changes see:
    http://cpansearch.perl.org/src/DANKOGAI/Encode-2.70/Changes
* Fri Jan 25 2013 chris@computersalat.de
- update to 2.47
  * Encode.pm
    POD Fixes: Copyright and mail address
  * Makefile.PL
    Added LICENSE => 'perl'
  * lib/Encode/GSM0338.pm t/gsm0338.t
    REALLY fixed RT#75670: Wrong decoding for GSM 3.38 character \x09
    ucm/gsm0338.ucm is dropped from MANIFEST since 2.25
    but I was fixing the wrong file!
    https://rt.cpan.org/Ticket/Display.html?id=75670
* Tue Aug 23 2011 lars@linux-schulserver.de
- rename the binaries as they conflict with the same (but older)
  ones in the perl package itself
- add perl-Encode-rpmlintrc to the sources list
* Mon Aug 22 2011 lars@linux-schulserver.de
- update to 2.44:
  + fixed n-byte heap-overflow in Unicode.xs and decode_xs
  + use constant DEBUG option (cpan #69735)
* Tue May 31 2011 coolo@novell.com
- updated to 2.43
  Several bugfixes, see Changes
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Thu Aug 26 2010 pascal.bleser@opensuse.org
- initial package (2.39)
